************
run_analysis
************

Analyze Locally
===============

.. autofunction:: sonnetsuiteshelper.run_analysis.analyze_local

Analyze Remotely
================

.. autofunction:: sonnetsuiteshelper.run_analysis.analyze_remote
